# Vision
# 
# Functions to view the world
#
# Gino Wuytjens

import pygame
from gamemath import distance

VISION_FOV_SCALAR = 12 # scale is passed around as width of objects, multiplying it by 12 gives a nicely scaled fov

# looks around in a 360 view to the world
# for those situations where looking ahead is just too limiting
# bounding_box - pygame.Rect, or anything with attributes 'centerx', 'centery', 'width' and 'height'
def lookAround(bounding_box, world):
	#Determine scale, larger objects have larger fields of view
	scale = (bounding_box.width+bounding_box.height)/2
	return lookAroundPoint(bounding_box.centerx, bounding_box.centery, scale, world)

# looks around in a 360 view to the world
# without bounding box
def lookAroundPoint(x, y, scale, world):
	#fov_mask = make_fovmask((x, y), scale)
	observations = []
	objs = [] #world.getObjects()
	for obj in objs:
		pos_rect = obj.rect # pygame.Rect that contains the position
		position = (pos_rect.centerx, pos_rect.centery)
		dist = distance((x, y), position)
		if dist < scale*VISION_FOV_SCALAR and dist != 0.0:
			observations.append((obj, dist))
	
	return observations
	
def make_fovmask((x, y), scale, size): # return pygame.Mask
	fov = make_fovsurface((x, y), scale, size)
	return pygame.mask.mask_from_surface(fov)

def make_fovsurface((x, y), scale, size):
	fov = pygame.Surface(size)
	black = pygame.Color('0x000000')
	fov.fill(black)
	fov.set_colorkey(black)
	pygame.draw.circle(fov, pygame.Color('0xFFFFFF'), (x, y), scale*VISION_FOV_SCALAR)
	return fov

def makeLight(radius, brightness):
	lightSurf = pygame.Surface((2*radius, 2*radius), pygame.locals.SRCALPHA)
	#lightSurf.set_colorkey([0, 0, 0])
	#lightSurf.fill([0, 0, 0, 0])
	for i in range(1,radius):
		#print brightness, radius
		alpha = brightness*i/radius
		#print alpha
		pygame.draw.circle(lightSurf, [0, 0, 0, alpha], [radius, radius], radius-i)
		alpha -= 1
	return lightSurf