# Game Rules: Round
#
# By Gino Wuytjens, 2012

import math
import logging
from time import time
from .. import events
from base.sprites.hudelements import Text

logger = logging.getLogger(__name__)


class Round:

    def __init__(self, game, victoryCondition=None):
        """Creates a round in a session. The round will end when victoryCondition.check(round) returns True"""

        logger.info("Creating round")

        self.game = game
        self.session = game.session
        self.current_map = self.game.session.current_map
        self.victoryCondition = victoryCondition
        self.startTime = None
        self.stopTime = None
        self.timeLimit = 60

    def start(self):
        """Starts the round."""

        self.startTime = time()

        self.timeText = Text(self.game, "Round time left: " + str(self.timeLimit), colour=(240, 52, 13), font="Futura, Euphemia", size=24)
        (x, y) = self.current_map.area
        self.timeText.center(x / 2, 20)

        self.game.session.events.push(events.ROUND_START)

        for player in self.session.players:
            player.spawn()

    def stop(self):
        self.stopTime = time()
        self.timeText.vanish()
        self.game.session.events.push(events.ROUND_STOP)

        for player in self.session.getLivePlayers():
            player.despawn()

    def tick(self, time_passed):
        self.timeText.setText("Round time left: " + str(math.trunc((self.startTime + self.timeLimit) - time())))

    def isFinished(self):
        """Checks if the round is finished."""

        now = time()
        if ((now - self.startTime) >= self.timeLimit) or len(self.session.getLivePlayers()) < 2:  # or self.victoryCondition.check(self):
            self.stop()
            return True
        return False
