# Explosion
# 
# An explosion with splash damage
#
# Gino Wuytjens

import pygame, logging

logger = logging.getLogger(__name__)

class Explosion(pygame.sprite.Sprite):
	"""An explosion with splash damage"""

	def __init__(self, game, position, magnitude):
		pygame.sprite.Sprite.__init__(self, game.hud)
		self.game = game
		self.spritesheet = game.session.current_map.spritesheet
		self.image = self.spritesheet.getSpriteImage('explosion small')
		self.rect = self.image.get_rect()
		self.rect.center = position
		self.magnitude = magnitude
		self.time_passed = 0
		self.phase = 0
		self.increment = 1
		self.explode()

	def explode(self):
		# surface to use when evaluating explosions
		#s = pygame.Surface(self.image.area)
		#black = pygame.Color('0x000000')
		#s.set_colorkey(black)
		#s.fill(black)
		#pygame.draw.circle(s, pygame.Color('0xFFFFFF'), self.rect.center, self.magnitude)

		for player in self.game.session.current_map.playersAt(self.rect.center, self.rect.width/2):
			logger.info("Explosion damaging player %s", player)
			player.damage(self.magnitude)

		#mask = pygame.mask.from_surface(s)
		#maskrects = mask.get_bounding_rects()
		#for object in self.world.objects:
		#	if (object.bbox.collidelist(maskrects) != -1):
		#		object.damage(self.magnitude*2)
	
	def update(self, time_passed):
		self.time_passed += time_passed

		if (self.time_passed > 100):
			
			if (self.phase == 2):
				self.increment = -1
			self.phase += self.increment

			if self.phase == 1:
				self.image = self.spritesheet.getSpriteImage('explosion medium')
			elif self.phase == 2:
				self.image = self.spritesheet.getSpriteImage('explosion large')
			elif self.phase == 0:
				self.image = self.spritesheet.getSpriteImage('explosion small')
			else:
				self.vanish()

	def vanish(self):
		for group in self.groups():
			group.remove(self)