# HUD Elements
#
# By Gino Wuytjens, 2012

import pygame
import logging

logger = logging.getLogger(__name__)


class Text(pygame.sprite.Sprite):

    def __init__(self, game, text, size=40, colour=(0, 0, 0), font=None, antialias=1):
        pygame.sprite.Sprite.__init__(self, game.hud)
        self.msg = text
        self.colour = colour
        self.font = pygame.font.SysFont(font, size)
        self.antialias = antialias

        self.image = self.font.render(str(self.msg), antialias, colour)
        self.rect = self.image.get_rect()
        self.rect.topleft = (0, 0)

        self.change = False

    def setFont(self, font, size=40):
        self.font = pygame.font.Font(font, size)
        self.change = True

    def setText(self, text):
        self.msg = text
        self.change = True

    def place(self, x=0, y=0):
        self.rect.topleft = (x, y)

    def center(self, x, y):
        self.rect.center = (x, y)

    def update(self, time_passed):
        if (self.change):
            self.image = self.font.render(str(self.msg), self.antialias, self.colour)
            self.change = False

    def vanish(self):
        for group in self.groups():
            group.remove(self)

class StatBar(pygame.sprite.Sprite):

    def __init__(self, owner):
        """Creates a statbar for the owner. Owner must have a tank attribute to determine placement and getHealth() and getFuel() methods."""
        pygame.sprite.Sprite.__init__(self, owner.game.hud)

        logger.info("Creating statbar for %s", owner)

        self.owner = owner
        self.totalHeight = 8
        self.image = pygame.Surface((owner.tank.rect.width, owner.tank.rect.height + self.totalHeight))
        self.image.set_colorkey((0, 0, 0))
        self.rect = self.image.get_rect()
        self.rect.topleft = owner.tank.rect.topleft
        #self.rect = owner.tank.rect

    def update(self, time_passed):
        self.rect.topleft = self.owner.tank.rect.topleft
        self.image.fill((0, 0, 0))

        health = self.owner.getHealth()
        if (health < 34):
            hbc = pygame.Color('0xBA3309')
        elif (health < 67):
            hbc = pygame.Color('0xDE9414')
        else:
            hbc = pygame.Color('0x4EC716')

        pygame.draw.line(self.image, hbc, (0, self.rect.height - self.totalHeight / 4 * 3), (round(self.rect.width / 100.0 * health), self.rect.height - self.totalHeight / 4 * 3), self.totalHeight / 2)

        fuel = self.owner.getFuel()
        fbc = pygame.Color('0x1B77E0')
        pygame.draw.line(self.image, fbc, (0, self.rect.height - self.totalHeight / 4), (round(self.rect.width / 100.0 * fuel), self.rect.height - self.totalHeight / 4), self.totalHeight / 2)

        pygame.draw.rect(self.image, pygame.Color('0x363636'), pygame.Rect(0, self.rect.height - self.totalHeight + 1, self.rect.width, self.totalHeight - 1), 1)

    def vanish(self):
        for group in self.groups():
            group.remove(self)


class BoundingBox(pygame.sprite.Sprite):

    def __init__(self, owner):
        pygame.sprite.Sprite.__init__(self, owner.game.hud)

        logger.info("Creating bounding box")

        self.owner = owner
        self.image = pygame.Surface((owner.rect.width, owner.rect.height))
        self.image.set_colorkey((0, 0, 0))
        self.rect = owner.rect
        pygame.draw.line(self.image, pygame.Color('0x00FF00'), (0, self.rect.height), (round(self.rect.width / 100.0 * self.owner.health), self.rect.height), 8)

        pygame.draw.rect(self.image, pygame.Color('0xFF0000'), pygame.rect.Rect(0, 0, owner.rect.width, owner.rect.height), 1)

    def vanish(self):
        for group in self.groups():
            group.remove(self)
