# Bullet and other projectiles
#
# By Gino Wuytjens, 2012

import pygame
import math
import sprite
import explosion
from .. import lib


class Projectile(sprite.OwnedObject, sprite.CollideableSprite):

    def __init__(self, owner, image, speed, strength):
        sprite.OwnedObject.__init__(self, owner)
        self.game = owner.game
        self.image = image
        self.strength = strength
        self.rect = image.get_rect()
        self.rect.center = owner.tank.getPos()
        angle = owner.turret.getAngle()
        self.image = lib.gamemath.rotate(self.image, angle * 180 / math.pi)
        sprite.CollideableSprite.__init__(self, pygame.Rect(self.rect.center, (10, 10)), owner.game.session.current_map, owner.game.playerSprites)
        self.setAngle(angle)
        self.setSpeed(speed)

    def update(self, time_passed):
        # No orientation changes possible
        (status, colliders, distance) = self.updatePosition(time_passed)
        self.rect.center = self.bbox.center

        if status == "clip":
            self.vanish()
        elif status != "ok":
            self.explode()

    def vanish(self):
        for group in self.groups():
            group.remove(self)

    def explode(self):
        explosion.Explosion(self.game, self.rect.center, 20)
        self.vanish()


class Bullet(Projectile):

    def __init__(self, owner):
        Projectile.__init__(self, owner, owner.game.session.current_map.spritesheet.getSpriteImage('bullet'), 80, 20)
