# Spritesheet / Tileset
#
# Gino Wuytjens

import os
import json
import pygame
from pygame.locals import *


class Spritesheet(object):
    def __init__(self, filename):
        config = json.load(file("data/" + filename))
        self.file = config["file"]
        self.tilesize = config["tilesize"]
        self.name = config["name"]
        self.key = config["key"]

        try:
            self.sheet = pygame.image.load(os.path.join('data', self.file)).convert()
        except pygame.error, message:
            logger.error("Unable to load spritesheet file %s", self.file)
            logger.error(message)
            raise SystemExit
        self.sprites = {}

        for tile in config["tiles"]:
            self.defineSprite(tile["name"], (tile["x"], tile["y"], self.tilesize, self.tilesize))

    def defineSprite(self, name, rect, colorkey=None):
        if not colorkey:
            colorkey = self.key
        rect = Rect(rect)
        sprite = pygame.Surface(rect.size).convert()
        sprite.blit(self.sheet, (0, 0), rect)
        if colorkey is not None:
            if colorkey is -1:
                colorkey = sprite.get_at((0, 0))
            sprite.set_colorkey(colorkey, RLEACCEL)
        self.sprites[name] = sprite

    def getSpriteImage(self, name):
        if self.knownSprite(name):
            return self.sprites[name]
        else:
            return self.sprites["error"]

    def knownSprite(self, name):
        return name in self.sprites

        # Arguments:
        # tile - name of tile from the spreadsheet to use
        # screensize - tuple (screen width, screen height)
    def makeTiledSurface(self, tile, screensize):
        surf = pygame.Surface(screensize).convert()
        numxtiles = screensize[0] / self.tilesize + 1
        numytiles = screensize[1] / self.tilesize + 1
        #topx = (width - width/self.tilesize*self.tilesize)/2
        #topy = (height - height/self.tilesize*self.tilesize)/2
        for x in range(numxtiles):
            for y in range(numytiles):
                surf.blit(self.getSpriteImage(tile), (self.tilesize * x, self.tilesize * y))
        return surf
